SIP Reference Guide
===================

.. toctree::
    :maxdepth: 2

    introduction
    examples
    command_line_tools
    specification_files
    directives
    annotations
    other_topics
    c_api
    abi_13
    abi_12
    pyproject_toml
    sipbuild_api
